# Examples

The following examples show advanced applications of *PLINDER* to real world problems.
Although they address a specific question, they can be easily adapted to use them for
your own purposes.

:::{toctree}
:maxdepth: 1
:glob:

./*
:::
